import { mapGetters as h, mapActions as d } from "vuex";
import { isArray as b, isEmpty as w, isBoolean as A, has as v, isNil as E } from "lodash-es";
import I from "../../datasets/datasetsFacets/DatasetsFacetsItem.vue.mjs";
import { getFacetTranslation as q, getCountryFlagImg as R, getTranslationFor as S } from "../../utils/helpers.mjs";
import $ from "../../datasets/datasetsFacets/SettingsFacet.vue.mjs";
import P from "../../facets/CatalogDetailsFacet.vue.mjs";
import { resolveComponent as n, openBlock as c, createElementBlock as p, createElementVNode as m, createVNode as G, createTextVNode as i, createCommentVNode as u, createBlock as g, Fragment as k, renderList as L, normalizeClass as M } from "vue";
import "./CataloguesFacets.vue2.mjs";
import B from "../../_virtual/_plugin-vue_export-helper.mjs";
const j = {
  name: "catalogueFacets",
  components: {
    SettingsFacet: $,
    DatasetsFacetsItem: I,
    CatalogDetailsFacet: P
  },
  dependencies: ["catalogService"],
  data() {
    return {
      cutoff: this.$env.content.catalogs.facets.cutoff,
      showClearButton: this.$env.content.catalogs.facets.showClearButton,
      showFacetsTitle: this.$env.content.catalogs.facets.showFacetsTitle,
      showCatalogDetails: !1,
      superCatalog: {},
      browser: {
        /* eslint-disable-next-line */
        isIE: (
          /*@cc_on!@*/
          !!document.documentMode
        )
      },
      defaultFacetOrder: this.$env.content.catalogs.facets.defaultFacetOrder,
      MIN_FACET_LIMIT: this.$env.content.catalogs.facets.MIN_FACET_LIMIT,
      MAX_FACET_LIMIT: this.$env.content.catalogs.facets.MAX_FACET_LIMIT,
      FACET_OPERATORS: this.$env.content.catalogs.facets.FACET_OPERATORS,
      FACET_GROUP_OPERATORS: this.$env.content.catalogs.facets.FACET_GROUP_OPERATORS,
      erpd: {
        yes: this.i18n.global.t("message.metadata.yes"),
        no: this.i18n.global.t("message.metadata.no"),
        property: this.i18n.global.t("message.datasetFacets.facets.erpdOnly"),
        title: this.i18n.global.t("message.datasetFacets.facets.erpd")
        // toolTipTitle: "TOOLTIP",//this.i18n.global.t('message.helpIcon.dataServices'),
      }
    };
  },
  computed: {
    ...h("catalogDetails", [
      "getCatalog"
    ]),
    ...h("catalogs", [
      "getAvailableFacets",
      "getCatalogsCount",
      "getFacetOperator",
      "getFacetGroupOperator",
      "getLimit",
      "getPage",
      "getFacets"
    ]),
    facetOperatorWatcher() {
      return this.getFacetOperator;
    },
    facetGroupOperatorWatcher() {
      return this.getFacetGroupOperator;
    },
    showMoreFacetsShown() {
      return this.$env.content.catalogs.facets.cutoff > 0 && this.$env.content.catalogs.facets.cutoff < this.getAvailableFacets.length;
    },
    getSortedFacets() {
      const t = this.getAvailableFacets, e = [];
      return this.defaultFacetOrder.forEach((a) => {
        t.forEach((s) => {
          a === s.id && s.items.length > 0 && e.push(s);
        });
      }), e;
    },
    // Returns the current catalog's available language ids
    // example: ['en', 'de', 'sv']
    catalogLanguageIds() {
      const t = this.getCatalog && this.getCatalog.languages;
      return b(t) ? t.map((e) => e && e.id).filter((e) => e) : [];
    }
  },
  methods: {
    isEmpty: w,
    isBoolean: A,
    has: v,
    isNil: E,
    getFacetTranslation: q,
    getCountryFlagImg: R,
    getTranslationFor: S,
    ...d("catalogDetails", [
      "loadCatalog"
    ]),
    ...d("catalogs", [
      "addFacet",
      "removeFacet",
      "setFacetOperator",
      "setFacetGroupOperator",
      "setPage",
      "setPageCount"
    ]),
    /**
     * @description Sorts an array of facets by their count.
     * @param {Array<Object>} facets - The facets to sort
     * @param {Number} facet.count - The amount of catalogs having this facet assigned
     * @param {String} facet.name - The name of this facet
     * @returns {Array<Object>}
     */
    toggleCutoff() {
      this.cutoff = this.cutoff >= 0 ? -1 : this.$env.content.datasets.facets.cutoff;
    },
    sortByCount(t, e) {
      return e === "scoring" ? t : t.slice().sort((a, s) => s.count - a.count !== 0 ? s.count - a.count : a.name < s.name ? -1 : 1);
    },
    facetTitle(t) {
      return t === "scoring" ? this.i18n.global.t("message.header.navigation.data.metadataquality") : t === "country" ? this.i18n.global.t("message.datasetFacets.facets.origin") : this.i18n.global.t(`message.datasetFacets.facets.${t.toLowerCase()}`);
    },
    /**
     * @description Returns whether a facet is selected or not.
     * @param field - The field of the facet to check.
     * @param facet - The facet to check.
     * @returns {boolean}
     */
    facetIsSelected(t, e) {
      const a = e.id;
      if (!Object.prototype.hasOwnProperty.call(this.$route.query, t))
        return !1;
      let s = this.$route.query[t];
      return Array.isArray(s) || (s = [s]), s.indexOf(a) > -1;
    },
    /**
     * @description Wrapping callback-function for a click on a facet.
     * @param field - The field of the clicked facet
     * @param facet - The clicked facet
     */
    facetClicked(t, e) {
      const a = e.id;
      this.toggleFacet(t, a);
    },
    clearFacets() {
      Object.keys(this.$route.query).some((t) => t !== "locale" && t !== "page" && this.$route.query[t].length) && this.$router.push({ query: { locale: this.$i18n.locale, page: "1" } }).catch((t) => {
        console.error(t);
      });
    },
    /**
     * @description Add/Remove a facet from the routers query parameters.
     * @param field - The field of the facet
     * @param facet - The given facet
     */
    toggleFacet(t, e) {
      var r, o;
      Object.prototype.hasOwnProperty.call(this.$route.query, [t]) || this.$router.push({ query: Object.assign({}, this.$route.query, { [t]: [] }) });
      let a = (o = (r = this.$route.query) == null ? void 0 : r[t]) == null ? void 0 : o.slice();
      a || (a = []), Array.isArray(a) || (a = [a]);
      const s = a.indexOf(e);
      s > -1 ? a.splice(s, 1) : a.push(e), this.$router.push({ query: Object.assign({}, this.$route.query, { [t]: a, page: 1 }) });
    },
    changeFacetOperator(t) {
      this.setFacetOperator(t), this.setFacetGroupOperator(t);
    },
    isErpd() {
      var a;
      const t = (a = this.$route.query) == null ? void 0 : a.superCatalog;
      return (t && t.constructor === Array ? t[0] : t) === "erpd" ? "true" : "false";
    },
    changeErpd(t) {
      var r;
      const e = "erpd", a = (r = this.$route.query) == null ? void 0 : r.superCatalog, s = a && a.constructor === Array ? a[0] : a;
      (t === "false" && s === e || t === "true" && s !== e) && (s === e && delete this.$route.query.showsubcatalogs, this.toggleFacet("superCatalog", e));
    },
    /**
     * @description Toggles the facetoperator between 'or'/'and'.
     */
    toggleFacetGroupOperator() {
      let t = this.getFacetGroupOperator;
      t = t === this.FACET_GROUP_OPERATORS.and ? this.FACET_GROUP_OPERATORS.or : this.FACET_GROUP_OPERATORS.and, this.setFacetGroupOperator(t);
    },
    resetPage() {
      this.$router.replace({ query: Object.assign({}, this.$route.query, { page: 1 }) });
    },
    triggerResize() {
      setTimeout(() => {
        window.dispatchEvent(new Event("resize"));
      }, 200);
    },
    getFacetCount(t, e) {
      return t.id === "scoring" ? "" : e.count;
    }
  },
  watch: {
    facetOperatorWatcher: {
      handler(t) {
        this.$router.replace({ query: Object.assign({}, this.$route.query, { facetOperator: t }) });
      }
    },
    facetGroupOperatorWatcher: {
      handler(t) {
        this.$router.replace({ query: Object.assign({}, this.$route.query, { facetGroupOperator: t }) });
      }
    },
    getCatalog(t) {
      this.superCatalog = t;
    }
  },
  created() {
    if (this.$route.query.showsubcatalogs) {
      const t = this.$route.query.superCatalog;
      if (typeof t == "string") {
        const e = t.substring(t.lastIndexOf("/") + 1);
        this.loadCatalog(e).then(
          (a) => {
          }
        );
      }
    }
  }
}, N = { class: "container catalog-facets" }, x = { class: "row mx-3 mr-md-0" }, D = { class: "col" }, U = {
  key: 0,
  class: "row h5 font-weight-bold mt-4 mb-3"
};
function W(t, e, a, s, r, o) {
  const F = n("catalog-details-facet"), C = n("settings-facet"), y = n("radio-facet"), O = n("select-facet"), _ = n("pv-show-more"), T = n("pv-button");
  return c(), p("div", N, [
    m("div", x, [
      m("div", D, [
        G(F, {
          class: "catalog-details",
          catalog: r.superCatalog,
          catalogLanguageIds: o.catalogLanguageIds
        }, null, 8, ["catalog", "catalogLanguageIds"]),
        e[1] || (e[1] = i()),
        r.showFacetsTitle ? (c(), p("span", U, "Filter by")) : u("", !0),
        e[2] || (e[2] = i()),
        r.showCatalogDetails ? u("", !0) : (c(), g(C, {
          key: 1,
          class: "row facet-field mb-3"
        })),
        e[3] || (e[3] = i()),
        (c(!0), p(k, null, L(o.getSortedFacets, (l, f) => (c(), p("div", {
          class: M(["row facet-field mb-3", { "mt-3": f > 0 }]),
          key: `facet@${f}`
        }, [
          l.id === "superCatalog" ? (c(), g(y, {
            key: 0,
            title: r.erpd.title,
            property: r.erpd.property,
            toolTipTitle: r.erpd.toolTipTitle,
            optionIds: ["true", "false"],
            optionLabels: [r.erpd.yes, r.erpd.no],
            initialOption: o.isErpd(),
            change: o.changeErpd
          }, null, 8, ["title", "property", "toolTipTitle", "optionLabels", "initialOption", "change"])) : u("", !0),
          e[0] || (e[0] = i()),
          l.id !== "superCatalog" ? (c(), g(O, {
            key: 1,
            fieldId: l.id,
            header: o.facetTitle(l.id),
            items: o.sortByCount(l.items, l.id),
            getFacetTranslationWrapper: o.getFacetTranslation,
            facetIsSelected: o.facetIsSelected,
            facetClicked: o.facetClicked,
            multiSelect: l.id !== "scoring",
            class: "col pr-0"
          }, null, 8, ["fieldId", "header", "items", "getFacetTranslationWrapper", "facetIsSelected", "facetClicked", "multiSelect"])) : u("", !0)
        ], 2))), 128)),
        e[4] || (e[4] = i()),
        o.showMoreFacetsShown ? (c(), g(_, {
          key: 2,
          label: r.cutoff >= 0 ? t.$t("message.datasetFacets.moreFilters") : t.$t("message.datasetFacets.lessFilters"),
          upArrow: r.cutoff === -1,
          action: o.toggleCutoff,
          class: "p-0 row facets-show-more"
        }, null, 8, ["label", "upArrow", "action"])) : u("", !0),
        e[5] || (e[5] = i()),
        r.showClearButton ? (c(), g(T, {
          key: 3,
          label: "Clear filters",
          class: "row mt-5 facets-clear",
          action: o.clearFacets
        }, null, 8, ["action"])) : u("", !0)
      ])
    ])
  ]);
}
const tt = /* @__PURE__ */ B(j, [["render", W], ["__scopeId", "data-v-47ab27ed"]]);
export {
  tt as default
};
//# sourceMappingURL=CataloguesFacets.vue.mjs.map
