import "../../config/styles/variables.css.mjs";
import { PhX as v, PhCheck as y } from "@phosphor-icons/vue";
import { resolveComponent as f, openBlock as d, createElementBlock as C, withDirectives as g, createElementVNode as o, vModelCheckbox as k, createTextVNode as a, normalizeStyle as c, createCommentVNode as n, normalizeClass as m, createBlock as h } from "vue";
import "./SwitchV3.vue2.mjs";
import x from "../../../_virtual/_plugin-vue_export-helper.mjs";
const b = {
  name: "SwitchV3",
  components: {
    PhX: v,
    PhCheck: y
  },
  data() {
    return {
      isChecked: this.defaultChecked,
      circleColor: "var(--neutral-0, #ffffff)",
      sliderBackgroundColor: "var(--neutral-20, #e6e7e9)",
      hoverCircleColor: "",
      showHoverCircle: !1,
      leftHoverCircle: "16px",
      topHoverCircle: "-4px",
      zHoverCircle: "-1",
      stateLock: !1,
      sliderPadding: "0 6px",
      circlePadding: "12px",
      circleHeight: "2px",
      circleWidth: "2px",
      sliderBorder: "",
      circleOpacity: "",
      blue60: "",
      neutral10: "",
      neutral30: "",
      interactionType: null,
      // mouse or keyboard
      pressedState: !1,
      sliderOnHoverState: !1
    };
  },
  props: {
    defaultChecked: {
      type: Boolean,
      default: !1
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    hasIcon: {
      type: Boolean,
      default: !1
    }
  },
  methods: {
    emitSwitchState() {
      this.$emit("switch-toggled", this.isChecked);
    },
    handleFocus() {
      this.updateHoverStyles();
    },
    handleBlur() {
      this.interactionType === "keyboard" && (this.sliderOnHoverState = !1, this.resetStyles());
    },
    handleKeydown(l) {
      this.interactionType = "keyboard", (l.key === "Enter" || l.key === " " || l.key === "Spacebar") && (l.preventDefault(), this.handlePressState());
    },
    handleKeyup(l) {
      this.interactionType = "keyboard", this.pressedState = !1, l.key === "Tab" ? (l.preventDefault(), this.updateHoverStyles()) : (l.key === "Enter" || l.key === " " || l.key === "Spacebar") && (l.preventDefault(), this.pressedState = !1, this.isChecked = !this.isChecked, this.emitSwitchState(), setTimeout(() => {
        this.updateHoverStyles();
      }, 10));
    },
    handleMouseDown() {
      this.disabled || this.stateLock || (this.interactionType = "mouse", this.handlePressState());
    },
    handlePressState() {
      this.pressedState = !0, this.circlePadding = "14px", this.isChecked ? (this.sliderPadding = "0px 2px", this.hoverCircleColor = "var( --state-layer-primary-opacity-12)") : (this.sliderPadding = "0px 10px 0px 0px", this.hoverCircleColor = "var( --state-layer-on-surface-opacity-12)", this.hasIcon || (this.leftHoverCircle = "-6px"));
    },
    handleMouseUp() {
      this.pressedState = !1, !(this.disabled || this.stateLock) && (this.sliderOnHoverState ? setTimeout(() => {
        this.updateHoverStyles();
      }, 10) : this.resetStyles());
    },
    onHover() {
      if (this.sliderOnHoverState = !0, !this.pressedState) {
        if (this.stateLock || this.disabled)
          return;
        this.showHoverCircle = !0, this.updateHoverStyles();
      }
    },
    onLeave() {
      this.sliderOnHoverState = !1, !(this.stateLock || this.disabled) && (this.showHoverCircle = !1, this.resetStyles());
    },
    resetStyles() {
      this.showHoverCircle = !1, this.pressedState = !1, this.isChecked ? (this.circleColor = "var(--neutral-0, #ffffff)", this.sliderBackgroundColor = "var(--blue-60, #009fe3)", this.circlePadding = "12px", this.sliderPadding = "0 var(--Spacing-1, 4px)") : (this.circleColor = "var(--neutral-60, #687178)", this.sliderBackgroundColor = "var(--neutral-20, #e6e7e9)", this.circlePadding = "8px", this.sliderPadding = "0 6px", this.hasIcon && (this.circlePadding = "12px", this.sliderPadding = "0 2px"));
    },
    updateHoverStyles() {
      this.showHoverCircle = !0, this.isChecked ? (this.circlePadding = "12px", this.sliderPadding = "0 var(--Spacing-1, 4px)", this.circleColor = "var(--blue-20, rgba(0, 159, 227, 0.2))", this.interactionType === "mouse" ? this.hoverCircleColor = "var(--state-layer-primary-opacity-8, rgba(0, 159, 227, 0.08))" : this.hoverCircleColor = "var(--state-layer-primary-opacity-12, rgba(0, 159, 227, 0.12))", this.leftHoverCircle = "16px", this.topHoverCircle = "-4px", this.sliderBackgroundColor = "var(--blue-60, #009fe3)", this.zHoverCircle = "-1") : (this.circlePadding = "8px", this.sliderPadding = "0 6px", this.circleColor = "var(--neutral-60, #687178)", this.interactionType === "mouse" ? this.hoverCircleColor = "var(--state-layer-on-surface-opacity-8, rgba(11, 26, 37, 0.08))" : this.hoverCircleColor = "var(--state-layer-on-surface-opacity-12, rgba(11, 26, 37, 0.12))", this.leftHoverCircle = "-6px", this.topHoverCircle = "-6px", this.sliderBackgroundColor = "var(--neutral-0, #ffffff)", this.circleColor = "var(--neutral-80)", this.zHoverCircle = "100", this.hasIcon && (this.circlePadding = "12px", this.sliderPadding = "0 2px", this.leftHoverCircle = "-6px", this.topHoverCircle = "-6px"));
    }
  },
  mounted() {
    this.blue60 = getComputedStyle(document.documentElement).getPropertyValue("--blue-60").trim(), this.neutral10 = getComputedStyle(document.documentElement).getPropertyValue("--neutral-10").trim(), this.neutral30 = getComputedStyle(document.documentElement).getPropertyValue("--neutral-30").trim(), this.defaultChecked ? (this.isChecked = !0, this.circleColor = "var(--neutral-0, #ffffff)", this.sliderBackgroundColor = "var(--blue-60, #009fe3)", this.sliderPadding = "0 var(--Spacing-1, 4px)") : (this.isChecked = !1, this.circleColor = "var(--neutral-60, #687178)", this.sliderBackgroundColor = "var(--neutral-20, #e6e7e9)", this.circlePadding = "8px", this.hasIcon && (this.circlePadding = "12px", this.sliderPadding = "0 2px")), this.disabled && (this.circleColor = "var(--neutral-5, #d9d9d9)", this.sliderBackgroundColor = "var(--neutral-30, #f0f0f0)", this.sliderBorder = "var(--neutral-30)", this.isChecked || (this.circleColor = "var(--neutral-60, #d9d9d9)", this.sliderBackgroundColor = "var(--neutral-10)", this.sliderBorder = "2px solid var(--neutral-30, #D5D7DA)", this.circleOpacity = "0.38"));
  }
}, S = ["disabled"], H = { class: "dpiV3_phosphor-icon-wrapper" }, P = { class: "dpiV3_phosphor-icon-wrapper" }, w = { class: "dpiV3_phosphor-icon-wrapper" }, B = { class: "dpiV3_phosphor-icon-wrapper" };
function V(l, e, s, I, r, t) {
  const u = f("PhCheck"), p = f("PhX");
  return d(), C("label", {
    style: { "margin-bottom": "0px !important" },
    class: "dpiV3_switch",
    onMousedown: e[6] || (e[6] = (...i) => t.handleMouseDown && t.handleMouseDown(...i)),
    onMouseup: e[7] || (e[7] = (...i) => t.handleMouseUp && t.handleMouseUp(...i)),
    onMouseover: e[8] || (e[8] = (...i) => t.onHover && t.onHover(...i)),
    onMouseleave: e[9] || (e[9] = (...i) => t.onLeave && t.onLeave(...i))
  }, [
    g(o("input", {
      tabindex: "0",
      type: "checkbox",
      "onUpdate:modelValue": e[0] || (e[0] = (i) => r.isChecked = i),
      disabled: s.disabled,
      onChange: e[1] || (e[1] = (...i) => t.emitSwitchState && t.emitSwitchState(...i)),
      onKeydown: e[2] || (e[2] = (...i) => t.handleKeydown && t.handleKeydown(...i)),
      onKeyup: e[3] || (e[3] = (...i) => t.handleKeyup && t.handleKeyup(...i)),
      onFocus: e[4] || (e[4] = (...i) => t.handleFocus && t.handleFocus(...i)),
      onBlur: e[5] || (e[5] = (...i) => t.handleBlur && t.handleBlur(...i))
    }, null, 40, S), [
      [k, r.isChecked]
    ]),
    e[14] || (e[14] = a()),
    o("span", {
      class: "dpiV3_slider",
      style: c({
        backgroundColor: r.sliderBackgroundColor,
        padding: r.sliderPadding,
        border: r.sliderBorder
      })
    }, [
      !s.disabled && r.showHoverCircle ? (d(), C("span", {
        key: 0,
        class: "dpiV3_hover-circle",
        style: c({
          backgroundColor: r.hoverCircleColor,
          left: r.leftHoverCircle,
          top: r.topHoverCircle,
          "z-index": r.zHoverCircle
        })
      }, null, 4)) : n("", !0),
      e[13] || (e[13] = a()),
      o("span", {
        class: m(["dpiV3_icon-wrapper", {
          "icon-present": s.hasIcon,
          "icon-absent": !s.hasIcon,
          active: r.isChecked
        }]),
        style: c({
          backgroundColor: r.circleColor,
          padding: r.circlePadding,
          height: r.circleHeight,
          width: r.circleWidth,
          opacity: r.circleOpacity
        })
      }, [
        o("div", H, [
          r.isChecked && s.hasIcon && !s.disabled ? (d(), h(u, {
            key: 0,
            size: 16,
            color: r.blue60,
            weight: "bold"
          }, null, 8, ["color"])) : n("", !0)
        ]),
        e[10] || (e[10] = a()),
        o("div", P, [
          !r.isChecked && s.hasIcon && !s.disabled ? (d(), h(p, {
            key: 0,
            size: "16px",
            weight: "bold",
            color: r.neutral10
          }, null, 8, ["color"])) : n("", !0)
        ]),
        e[11] || (e[11] = a()),
        o("div", w, [
          !r.isChecked && s.hasIcon && s.disabled ? (d(), h(p, {
            key: 0,
            size: "16px",
            weight: "bold",
            color: r.neutral30
          }, null, 8, ["color"])) : n("", !0)
        ]),
        e[12] || (e[12] = a()),
        o("div", B, [
          r.isChecked && s.hasIcon && s.disabled ? (d(), h(u, {
            key: 0,
            size: 16,
            color: r.neutral30,
            weight: "bold"
          }, null, 8, ["color"])) : n("", !0)
        ])
      ], 6)
    ], 4)
  ], 32);
}
const L = /* @__PURE__ */ x(b, [["render", V], ["__scopeId", "data-v-cdfade5d"]]);
export {
  L as default
};
//# sourceMappingURL=SwitchV3.vue.mjs.map
